@@ -2,6 +2,9 @@
 
 import argparse
 import bz2
+import csv
+import datetime
+import decimal
 import gzip
 import itertools
 import lzma
@@ -10,9 +13,15 @@ import warnings
 from os.path import splitext
 
 import agate
+from agate.data_types.base import DEFAULT_NULL_VALUES
 
 from csvkit.exceptions import ColumnIdentifierError, RequiredHeaderError
 
+try:
+    import zstandard
+except ImportError:
+    zstandard = None
+
 
 class LazyFile:
     """
@@ -32,10 +41,7 @@ class LazyFile:
         self._lazy_kwargs = kwargs
 
     def __getattr__(self, name):
-        if not self._is_lazy_opened:
-            self.f = self.init(*self._lazy_args, **self._lazy_kwargs)
-            self._is_lazy_opened = True
-
+        self._open()
         return getattr(self.f, name)
 
     def __iter__(self):
@@ -48,12 +54,14 @@ class LazyFile:
             self._is_lazy_opened = False
 
     def __next__(self):
+        self._open()
+        return next(self.f).replace('\0', '')
+
+    def _open(self):
         if not self._is_lazy_opened:
             self.f = self.init(*self._lazy_args, **self._lazy_kwargs)
             self._is_lazy_opened = True
 
-        return next(self.f)
-
 
 class CSVKitUtility:
     description = ''
@@ -85,7 +93,7 @@ class CSVKitUtility:
         # Without this fix you will see at the end:
         #  [Errno 32] Broken pipe
         # With this fix, there should be no error
-        # For details on Python and SIGPIPE, see http://bugs.python.org/issue1652
+        # For details on Python and SIGPIPE, see https://bugs.python.org/issue1652
         try:
             import signal
             signal.signal(signal.SIGPIPE, signal.SIG_DFL)
@@ -187,6 +195,10 @@ class CSVKitUtility:
             self.argparser.add_argument(
                 '--blanks', dest='blanks', action='store_true',
                 help='Do not convert "", "na", "n/a", "none", "null", "." to NULL.')
+        if 'blanks' not in self.override_flags:
+            self.argparser.add_argument(
+                '--null-value', dest='null_values', nargs='+', default=[],
+                help='Convert this value to NULL. --null-value can be specified multiple times.')
         if 'date-format' not in self.override_flags:
             self.argparser.add_argument(
                 '--date-format', dest='date_format',
@@ -224,14 +236,17 @@ class CSVKitUtility:
                      '1-based numbering.')
 
         self.argparser.add_argument(
-            '-V', '--version', action='version', version='%(prog)s 1.1.1',
+            '-V', '--version', action='version', version='%(prog)s 1.5.0',
             help='Display version information and exit.')
 
-    def _open_input_file(self, path):
+    def _open_input_file(self, path, opened=False):
         """
         Open the input file specified on the command line.
         """
         if not path or path == '-':
+            # "UnsupportedOperation: It is not possible to set the encoding or newline of stream after the first read"
+            if not opened:
+                sys.stdin.reconfigure(encoding=self.args.encoding)
             f = sys.stdin
         else:
             extension = splitext(path)[1]
@@ -240,8 +255,10 @@ class CSVKitUtility:
                 func = gzip.open
             elif extension == '.bz2':
                 func = bz2.open
-            elif extension == ".xz":
+            elif extension == '.xz':
                 func = lzma.open
+            elif extension == '.zst' and zstandard:
+                func = zstandard.open
             else:
                 func = open
 
@@ -255,12 +272,16 @@ class CSVKitUtility:
         """
         kwargs = {}
 
+        field_size_limit = getattr(self.args, 'field_size_limit')
+        if field_size_limit is not None:
+            csv.field_size_limit(field_size_limit)
+
         if self.args.tabs:
             kwargs['delimiter'] = '\t'
         elif self.args.delimiter:
             kwargs['delimiter'] = self.args.delimiter
 
-        for arg in ('quotechar', 'quoting', 'doublequote', 'escapechar', 'field_size_limit', 'skipinitialspace'):
+        for arg in ('quotechar', 'quoting', 'doublequote', 'escapechar', 'skipinitialspace'):
             value = getattr(self.args, arg)
             if value is not None:
                 kwargs[arg] = value
@@ -296,15 +317,17 @@ class CSVKitUtility:
                                      'flag or with the PYTHONIOENCODING environment variable. Use the -v flag to see '
                                      'the complete error.\n' % self.args.encoding)
                 else:
-                    sys.stderr.write('{}: {}\n'.format(t.__name__, str(value)))
+                    sys.stderr.write(f'{t.__name__}: {str(value)}\n')
 
         sys.excepthook = handler
 
     def get_column_types(self):
         if getattr(self.args, 'blanks', None):
-            type_kwargs = {'null_values': ()}
+            type_kwargs = {'null_values': []}
         else:
-            type_kwargs = {}
+            type_kwargs = {'null_values': list(DEFAULT_NULL_VALUES)}
+        for null_value in getattr(self.args, 'null_values', []):
+            type_kwargs['null_values'].append(null_value)
 
         text_type = agate.Text(**type_kwargs)
 
@@ -369,7 +392,7 @@ class CSVKitUtility:
             self.args.columns,
             column_names,
             column_offset,
-            getattr(self.args, 'not_columns', None)
+            getattr(self.args, 'not_columns', None),
         )
 
         return rows, column_names, column_ids
@@ -403,6 +426,20 @@ def isatty(f):
         return False
 
 
+def default_str_decimal(obj):
+    if isinstance(obj, (datetime.date, datetime.datetime)):
+        return obj.isoformat()
+    if isinstance(obj, decimal.Decimal):
+        return str(obj)
+    raise TypeError(f'{repr(obj)} is not JSON serializable')
+
+
+def default_float_decimal(obj):
+    if isinstance(obj, decimal.Decimal):
+        return float(obj)
+    return default_str_decimal(obj)
+
+
 def make_default_headers(n):
     """
     Make a set of simple, default headers for files that are missing them.
@@ -466,15 +503,8 @@ def parse_column_identifiers(ids, column_names, column_offset=1, excluded_column
                     raise
 
                 try:
-                    if a:
-                        a = int(a)
-                    else:
-                        a = 1
-                    if b:
-                        b = int(b) + 1
-                    else:
-                        b = len(column_names) + 1
-
+                    a = int(a) if a else 1
+                    b = int(b) + 1 if b else len(column_names) + 1
                 except ValueError:
                     raise ColumnIdentifierError(
                         "Invalid range %s. Ranges must be two integers separated by a - or : character.")
@@ -499,15 +529,8 @@ def parse_column_identifiers(ids, column_names, column_offset=1, excluded_column
                     raise
 
                 try:
-                    if a:
-                        a = int(a)
-                    else:
-                        a = 1
-                    if b:
-                        b = int(b) + 1
-                    else:
-                        b = len(column_names)
-
+                    a = int(a) if a else 1
+                    b = int(b) + 1 if b else len(column_names)
                 except ValueError:
                     raise ColumnIdentifierError(
                         "Invalid range %s. Ranges must be two integers separated by a - or : character.")
